@@ -39,17 +39,17 @@ ssl_verify_modes = {
 
 auth_factories = {
     "login": lambda config: imap.LoginAuthenticator(
-                    config["username"],
-                    config["password"]),
+                    config["login_username"],
+                    config["login_password"]),
     "plain": lambda config: imap.PlainAuthenticator(
-                    config["identity"],
-                    config["password"],
-                    config["authorization_identity"]),
+                    config["plain_identity"],
+                    config["plain_password"],
+                    config["plain_authorization_identity"]),
     "oauth2": lambda config: imap.OAuth2Authenticator(
-                    config["user"],
-                    config["access_token"],
-                    config["mech"],
-                    config["vendor"])
+                    config["oauth2_user"],
+                    config["oauth2_access_token"],
+                    config["oauth2_mech"],
+                    config["oauth2_vendor"])
 }
 
 def main(argv = sys.argv):
@@ -65,9 +65,6 @@ def main(argv = sys.argv):
         help = "IMAP server")
     args = parser.parse_args(args = argv[1:])
 
-    with open(args.config) as stream:
-        config = yaml.load(stream)
-
     # read configuration
     validator = cerberus.Validator(schema.config)
     with open(args.config) as stream:
@@ -135,7 +132,8 @@ def main(argv = sys.argv):
                     "{}: policy not defined".format(policy))
             sessions.append(imap.Session(server, port,
                 tls_mode, ssl_context, authenticator,
-                server_config["poll"], mailbox, policies[policy]))
+                server_config["poll"], server_config["idle"],
+                mailbox, policies[policy]))
 
     # run sessions
     for session in sessions:
